@@ -1,6 +1,6 @@
 package Mason::Filters::Standard;
 BEGIN {
-  $Mason::Filters::Standard::VERSION = '2.18';
+  $Mason::Filters::Standard::VERSION = '2.19';
 }
 use Mason::DynamicFilter;
 use Mason::Util;
@@ -39,6 +39,10 @@ method Repeat ($times) {
     );
 }
 
+method Tee ($outref) {
+    sub { $$outref = $_[0]; return $_[0] }
+}
+
 method Trim () {
     sub { Mason::Util::trim( $_[0] ) }
 }
@@ -64,7 +68,8 @@ L<Mason::Component|Mason::Component>.
 
 =item Capture ($ref)
 
-Uses C<< $m->capture >> to capture the content in I<$ref>.
+Uses C<< $m->capture >> to capture the content in I<$ref> instead of outputting
+it.
 
     % $.Capture(\my $content) {{
       <!-- this will end up in $content -->
@@ -123,6 +128,19 @@ each time, which may result in different content.
        <% $i++ %><br>
     % }}
 
+=item Tee ($ref)
+
+Uses C<< $m->capture >> to capture the content in I<$ref>, and also output it.
+
+    % $.Tee(\my $content) {{
+      <!-- this will end up in $content and also be output -->
+    % }}
+
+    ...
+
+    <!-- output content again down here -->
+    <% $content %>
+
 =item Trim
 
 Remove whitespace from the beginning and end of the content.
