@@ -1,6 +1,6 @@
 package Mason::Moose;
 BEGIN {
-  $Mason::Moose::VERSION = '2.18';
+  $Mason::Moose::VERSION = '2.19';
 }
 use Moose                      ();
 use MooseX::HasDefaults::RO    ();
@@ -17,8 +17,8 @@ sub init_meta {
     my $for_class = $params{for_class};
     Method::Signatures::Simple->import( into => $for_class );
     Moose->init_meta(@_);
-    MooseX::StrictConstructor->init_meta(@_);
-    MooseX::HasDefaults::RO->init_meta(@_);
+    MooseX::StrictConstructor->import( { into => $for_class } );
+    MooseX::HasDefaults::RO->import( { into => $for_class } );
     {
         no strict 'refs';
         *{ $for_class . '::CLASS' } = sub () { $for_class };    # like CLASS.pm
